var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/use-id.ts
import { computed, onBeforeMount, onMounted, ref } from "vue";
var serverHandoffComplete = false;
var _id = 0;
var genId = /* @__PURE__ */ __name(() => ++_id, "genId");
var useId = /* @__PURE__ */ __name((id, prefix) => {
  const initialId = id || (serverHandoffComplete ? genId() : null);
  const uid = ref(initialId);
  onBeforeMount(() => {
    if (serverHandoffComplete === false) {
      serverHandoffComplete = true;
    }
  });
  onMounted(() => {
    if (uid.value === null) {
      uid.value = genId();
    }
  });
  return computed(() => {
    const __id__ = uid.value !== null ? uid.value.toString() : void 0;
    return prefix ? `${prefix}-${__id__}` : __id__;
  });
}, "useId");
function useIds(id, ...prefixes) {
  const __id__ = useId(id);
  return prefixes.map((prefix) => computed(() => `${prefix}-${__id__.value}`));
}
__name(useIds, "useIds");

// src/use-event-listener.ts
import { unref, watch } from "vue";
import { isString, noop } from "@chakra-ui/utils";
import { defaultWindow, tryOnScopeDispose } from "@chakra-ui/vue-utils";
function useEventListener(...args) {
  let target;
  let event;
  let listener;
  let options;
  if (isString(args[0])) {
    ;
    [event, listener, options] = args;
    target = defaultWindow;
  } else {
    ;
    [target, event, listener, options] = args;
  }
  if (!target)
    return noop;
  let cleanup = noop;
  const stopWatch = watch(() => unref(target), (el) => {
    cleanup();
    if (!el)
      return;
    el.addEventListener(event, listener, options);
    cleanup = /* @__PURE__ */ __name(() => {
      el.removeEventListener(event, listener, options);
      cleanup = noop;
    }, "cleanup");
  }, {
    immediate: true,
    flush: "post"
  });
  const stop = /* @__PURE__ */ __name(() => {
    stopWatch();
    cleanup();
  }, "stop");
  tryOnScopeDispose(stop);
  return stop;
}
__name(useEventListener, "useEventListener");

// src/use-window-event.ts
import { watchEffect } from "vue";
function useWindowEvent(type, listener, options) {
  if (typeof window === "undefined")
    return;
  watchEffect((onInvalidate) => {
    window.addEventListener(type, listener, options);
    onInvalidate(() => {
      window.removeEventListener(type, listener, options);
    });
  });
}
__name(useWindowEvent, "useWindowEvent");

// src/use-element-stack.ts
import {
  inject,
  provide,
  watchEffect as watchEffect2
} from "vue";
var StackContext = Symbol("ChakraElementStackContext");
var StackMessage = /* @__PURE__ */ ((StackMessage2) => {
  StackMessage2[StackMessage2["AddElement"] = 0] = "AddElement";
  StackMessage2[StackMessage2["RemoveElement"] = 1] = "RemoveElement";
  return StackMessage2;
})(StackMessage || {});
function useStackContext() {
  return inject(StackContext, () => {
  });
}
__name(useStackContext, "useStackContext");
function useElementStack(element) {
  let notify = useStackContext();
  watchEffect2((onInvalidate) => {
    let domElement = element == null ? void 0 : element.value;
    if (!domElement)
      return;
    notify(0 /* AddElement */, domElement);
    onInvalidate(() => notify(1 /* RemoveElement */, domElement));
  });
}
__name(useElementStack, "useElementStack");
function useStackProvider(onUpdate) {
  let parentUpdate = useStackContext();
  function notify(...args) {
    onUpdate == null ? void 0 : onUpdate(...args);
    parentUpdate(...args);
  }
  __name(notify, "notify");
  provide(StackContext, notify);
}
__name(useStackProvider, "useStackProvider");

// src/use-clipboard.ts
import { ref as ref2, unref as unref2 } from "vue";
function useClipboard({
  source,
  copyTimeout = 1e3,
  read = false
}) {
  const isSupported = Boolean(navigator && "clipboard" in navigator);
  const text = ref2("");
  const copied = ref2(false);
  const timeout = /* @__PURE__ */ __name(() => {
    let t = setTimeout(() => {
      copied.value = false;
    }, copyTimeout);
  }, "timeout");
  const events = ["copy", "cut"];
  if (isSupported && read) {
    for (const event of events)
      useEventListener(event, updateText);
  }
  function updateText() {
    navigator.clipboard.readText().then((value) => {
      text.value = value;
    });
  }
  __name(updateText, "updateText");
  async function copy(_value = unref2(source)) {
    const value = unref2(_value);
    if (isSupported && value != null) {
      await navigator.clipboard.writeText(value);
      text.value = value;
      copied.value = true;
      timeout();
    }
  }
  __name(copy, "copy");
  return {
    copy,
    text,
    copied
  };
}
__name(useClipboard, "useClipboard");

// src/use-disclosure.ts
import { computed as computed2, ref as ref3, watchEffect as watchEffect3 } from "vue";
function useDisclosure(props = {}) {
  const {
    isOpen: isOpenProp,
    onClose: handleClose,
    onOpen: handleOpen,
    id: idProp,
    defaultIsOpen
  } = props;
  const isOpenState = ref3(defaultIsOpen || false);
  const isOpen = ref3(isOpenProp !== void 0 ? isOpenProp : isOpenState.value);
  const isControlled = isOpenProp !== void 0;
  const uid = useId();
  const id = computed2(() => idProp != null ? idProp : `disclosure-${uid.value}`);
  const close = /* @__PURE__ */ __name(() => {
    if (!isControlled) {
      isOpenState.value = false;
    }
    handleClose == null ? void 0 : handleClose();
  }, "close");
  const open = /* @__PURE__ */ __name(() => {
    if (!isControlled) {
      isOpenState.value = true;
    }
    handleOpen == null ? void 0 : handleOpen();
  }, "open");
  const toggle = /* @__PURE__ */ __name(() => isOpen.value ? close() : open(), "toggle");
  const buttonProps = computed2(() => ({
    "aria-expanded": isOpen.value,
    "aria-controls": id.value,
    onClick() {
      toggle();
    }
  }));
  const disclosureProps = computed2(() => ({
    hidden: !isOpen.value,
    id: id.value
  }));
  watchEffect3(() => {
    isOpen.value = isOpenState.value;
  });
  return {
    isOpen,
    open,
    close,
    toggle,
    isControlled,
    buttonProps,
    disclosureProps
  };
}
__name(useDisclosure, "useDisclosure");

// src/use-counter.ts
import { clampValue, countDecimalPlaces, toPrecision } from "@chakra-ui/utils";
import { ref as ref4, watchEffect as watchEffect4 } from "vue";
function useCounter(props = {}) {
  const {
    precision: precisionProp,
    defaultValue = 0,
    step: stepProp = 1,
    min = Number.MIN_SAFE_INTEGER,
    max = Number.MAX_SAFE_INTEGER,
    keepWithinRange = true
  } = props;
  const valueState = ref4((() => {
    var _a;
    if (defaultValue == null)
      return "";
    return (_a = cast(defaultValue, stepProp, precisionProp)) != null ? _a : "";
  })());
  const decimalPlaces = ref4(0);
  let precision;
  const update = /* @__PURE__ */ __name((next) => {
    if (next === valueState.value)
      return;
    valueState.value = toPrecision(parse(next), precision).toString();
  }, "update");
  const clamp = /* @__PURE__ */ __name((value) => {
    let nextValue = value;
    if (keepWithinRange) {
      nextValue = clampValue(nextValue, min, max);
    }
    return toPrecision(nextValue, precision);
  }, "clamp");
  const increment = /* @__PURE__ */ __name((step = stepProp) => {
    let next;
    if (valueState.value === "") {
      next = parse(step);
    } else {
      next = parse(valueState.value) + step;
    }
    next = clamp(next);
    update(next);
  }, "increment");
  const decrement = /* @__PURE__ */ __name((step = stepProp) => {
    let next;
    if (valueState.value === "") {
      next = parse(-step);
    } else {
      next = parse(valueState.value) - step;
    }
    next = clamp(next);
    update(next);
  }, "decrement");
  const isOutOfRange = ref4(false);
  const valueAsNumber = ref4(0);
  watchEffect4(() => {
    decimalPlaces.value = getDecimalPlaces(parse(valueState.value), stepProp);
    precision = precisionProp != null ? precisionProp : decimalPlaces.value;
    valueAsNumber.value = parse(valueState.value);
    isOutOfRange.value = valueAsNumber.value > max || valueAsNumber.value < min;
  });
  return {
    decrement,
    increment,
    update,
    valueAsNumber,
    isOutOfRange,
    value: valueState
  };
}
__name(useCounter, "useCounter");
function parse(value) {
  return parseFloat(value.toString().replace(/[^\w.-]+/g, ""));
}
__name(parse, "parse");
function getDecimalPlaces(value, step) {
  return Math.max(countDecimalPlaces(step), countDecimalPlaces(value));
}
__name(getDecimalPlaces, "getDecimalPlaces");
function cast(value, step, precision) {
  const parsedValue = parse(value);
  if (Number.isNaN(parsedValue))
    return void 0;
  const decimalPlaces = getDecimalPlaces(parsedValue, step);
  return toPrecision(parsedValue, precision != null ? precision : decimalPlaces);
}
__name(cast, "cast");
export {
  StackMessage,
  useClipboard,
  useCounter,
  useDisclosure,
  useElementStack,
  useEventListener,
  useId,
  useIds,
  useStackContext,
  useStackProvider,
  useWindowEvent
};
